@@ -110,8 +110,11 @@ ArvBuffer * 		arv_buffer_new_full		(size_t size, void *preallocated,
 
 ArvBufferStatus		arv_buffer_get_status		(ArvBuffer *buffer);
 
+const void *		arv_buffer_get_user_data	(ArvBuffer *buffer);
+
 ArvBufferPayloadType	arv_buffer_get_payload_type	(ArvBuffer *buffer);
 guint64			arv_buffer_get_timestamp	(ArvBuffer *buffer);
+guint32 		arv_buffer_get_frame_id 	(ArvBuffer *buffer);
 const void *		arv_buffer_get_data		(ArvBuffer *buffer, size_t *size);
 
 void			arv_buffer_get_image_region		(ArvBuffer *buffer, gint *x, gint *y, gint *width, gint *height);
