@@ -1,4 +1,5 @@
 #include <arv.h>
+#include <arvstr.h>
 #include <stdlib.h>
 #include <signal.h>
 #include <stdio.h>
@@ -19,6 +20,11 @@ static gboolean arv_option_auto_socket_buffer = FALSE;
 static gboolean arv_option_no_packet_resend = FALSE;
 static unsigned int arv_option_packet_timeout = 20;
 static unsigned int arv_option_frame_retention = 100;
+static int arv_option_gv_stream_channel = -1;
+static int arv_option_gv_packet_delay = -1;
+static int arv_option_gv_packet_size = -1;
+static gboolean arv_option_realtime = FALSE;
+static gboolean arv_option_high_priority = FALSE;
 static char *arv_option_chunks = NULL;
 
 static const GOptionEntry arv_option_entries[] =
@@ -84,9 +90,29 @@ static const GOptionEntry arv_option_entries[] =
 		&arv_option_frame_retention, 		"Frame retention (ms)", NULL
 	},
 	{
-		"chunks", 				'c', 0, G_OPTION_ARG_STRING,
+		"gv-stream-channel",			'c', 0, G_OPTION_ARG_INT,
+		&arv_option_gv_stream_channel,		"GigEVision stream channel id", NULL
+	},
+	{
+		"gv-packet-delay",			'y', 0, G_OPTION_ARG_INT,
+		&arv_option_gv_packet_delay,		"GigEVision packet delay (ns)", NULL
+	},
+	{
+		"gv-packet-size",			'i', 0, G_OPTION_ARG_INT,
+		&arv_option_gv_packet_size,		"GigEVision packet size (bytes)", NULL
+	},
+	{
+		"chunks", 				'u', 0, G_OPTION_ARG_STRING,
 		&arv_option_chunks,	 		"Chunks", NULL
 	},
+	{
+		"realtime",				'\0', 0, G_OPTION_ARG_NONE,
+		&arv_option_realtime,			"Make stream thread realtime", NULL
+	},
+	{
+		"high-priority",			'\0', 0, G_OPTION_ARG_NONE,
+		&arv_option_high_priority,		"Make stream thread high priority", NULL
+	},
 	{
 		"debug", 				'd', 0, G_OPTION_ARG_STRING,
 		&arv_option_debug_domains, 		"Debug domains", NULL
@@ -134,6 +160,20 @@ new_buffer_cb (ArvStream *stream, ApplicationData *data)
 	}
 }
 
+static void
+stream_cb (void *user_data, ArvStreamCallbackType type, ArvBuffer *buffer)
+{
+	if (type == ARV_STREAM_CALLBACK_TYPE_INIT) {
+		if (arv_option_realtime) {
+			if (!arv_make_thread_realtime (10))
+				printf ("Failed to make stream thread realtime\n");
+		} else if (arv_option_high_priority) {
+			if (!arv_make_thread_high_priority (-10))
+				printf ("Failed to make stream thread high priority\n");
+		}
+	}
+}
+
 static gboolean
 periodic_task_cb (void *abstract_data)
 {
@@ -180,6 +220,7 @@ main (int argc, char **argv)
 
 	data.buffer_count = 0;
 	data.chunks = NULL;
+	data.chunk_parser = NULL;
 
 	arv_g_thread_init (NULL);
 	arv_g_type_init ();
@@ -217,8 +258,21 @@ main (int argc, char **argv)
 		guint software_trigger_source = 0;
 
 		if (arv_option_chunks != NULL) {
-			data.chunks = g_strsplit_set (arv_option_chunks, " ,:;", -1);
+			char *striped_chunks;
+
+			striped_chunks = g_strdup (arv_option_chunks);
+			arv_str_strip (striped_chunks, " ,:;", ',');
+			data.chunks = g_strsplit_set (striped_chunks, ",", -1);
+			g_free (striped_chunks);
+
 			data.chunk_parser = arv_camera_create_chunk_parser (camera);
+
+			for (i = 0; data.chunks[i] != NULL; i++) {
+				char *chunk = g_strdup_printf ("Chunk%s", data.chunks[i]);
+
+				g_free (data.chunks[i]);
+				data.chunks[i] = chunk;
+			}
 		}
 
 		arv_camera_set_chunks (camera, arv_option_chunks);
@@ -226,6 +280,12 @@ main (int argc, char **argv)
 		arv_camera_set_binning (camera, arv_option_horizontal_binning, arv_option_vertical_binning);
 		arv_camera_set_exposure_time (camera, arv_option_exposure_time_us);
 		arv_camera_set_gain (camera, arv_option_gain);
+		
+		if (arv_camera_is_gv_device (camera)) {
+			arv_camera_gv_select_stream_channel (camera, arv_option_gv_stream_channel);
+			arv_camera_gv_set_packet_delay (camera, arv_option_gv_packet_delay);
+			arv_camera_gv_set_packet_size (camera, arv_option_gv_packet_size);
+		}
 
 		arv_camera_get_region (camera, &x, &y, &width, &height);
 		arv_camera_get_binning (camera, &dx, &dy);
@@ -233,18 +293,25 @@ main (int argc, char **argv)
 		payload = arv_camera_get_payload (camera);
 		gain = arv_camera_get_gain (camera);
 
-		printf ("vendor name         = %s\n", arv_camera_get_vendor_name (camera));
-		printf ("model name          = %s\n", arv_camera_get_model_name (camera));
-		printf ("device id           = %s\n", arv_camera_get_device_id (camera));
-		printf ("image width         = %d\n", width);
-		printf ("image height        = %d\n", height);
-		printf ("horizontal binning  = %d\n", dx);
-		printf ("vertical binning    = %d\n", dy);
-		printf ("payload             = %d bytes\n", payload);
-		printf ("exposure            = %g µs\n", exposure);
-		printf ("gain                = %d dB\n", gain);
+		printf ("vendor name           = %s\n", arv_camera_get_vendor_name (camera));
+		printf ("model name            = %s\n", arv_camera_get_model_name (camera));
+		printf ("device id             = %s\n", arv_camera_get_device_id (camera));
+		printf ("image width           = %d\n", width);
+		printf ("image height          = %d\n", height);
+		printf ("horizontal binning    = %d\n", dx);
+		printf ("vertical binning      = %d\n", dy);
+		printf ("payload               = %d bytes\n", payload);
+		printf ("exposure              = %g µs\n", exposure);
+		printf ("gain                  = %d dB\n", gain);
 
-		stream = arv_camera_create_stream (camera, NULL, NULL);
+		if (arv_camera_is_gv_device (camera)) {
+			printf ("gv n_stream channels  = %d\n", arv_camera_gv_get_n_stream_channels (camera));
+			printf ("gv current channel    = %d\n", arv_camera_gv_get_current_stream_channel (camera));
+			printf ("gv packet delay       = %" G_GINT64_FORMAT " ns\n", arv_camera_gv_get_packet_delay (camera));
+			printf ("gv packet size        = %d bytes\n", arv_camera_gv_get_packet_size (camera));
+		}
+
+		stream = arv_camera_create_stream (camera, stream_cb, NULL);
 		if (stream != NULL) {
 			if (ARV_IS_GV_STREAM (stream)) {
 				if (arv_option_auto_socket_buffer)
