@@ -138,51 +138,64 @@ arv_viewer_update_device_list_cb (ArvViewer *viewer)
 		gtk_widget_set_sensitive (viewer->camera_combo_box, FALSE);
 }
 
+static GstBuffer *
+_arv_to_gst_buffer (ArvBuffer *arv_buffer) 
+{
+	GstBuffer *buffer;
+	int arv_row_stride;
+	int width, height;
+	char *buffer_data;
+	size_t buffer_size;
+
+	buffer_data = (char *) arv_buffer_get_data (arv_buffer, &buffer_size);
+	arv_buffer_get_image_region (arv_buffer, NULL, NULL, &width, &height);
+	arv_row_stride = width * ARV_PIXEL_FORMAT_BIT_PER_PIXEL (arv_buffer_get_image_pixel_format (arv_buffer)) / 8;
+
+	/* Gstreamer requires row stride to be a multiple of 4 */
+	if ((arv_row_stride & 0x3) != 0) {
+		int gst_row_stride;
+		size_t size;
+		void *data;
+		int i;
+
+		gst_row_stride = (arv_row_stride & ~(0x3)) + 4;
+
+		size = height * gst_row_stride;
+		data = g_malloc (size);	
+
+		for (i = 0; i < height; i++)
+			memcpy (((char *) data) + i * gst_row_stride, buffer_data + i * arv_row_stride, arv_row_stride);
+
+		buffer = gst_buffer_new_wrapped (data, size);
+	} else {
+		buffer = gst_buffer_new_wrapped_full (GST_MEMORY_FLAG_READONLY,
+						      buffer_data, buffer_size,
+						      0, buffer_size, NULL, NULL);
+	}
+
+	GST_BUFFER_DTS (buffer) = 0;
+	GST_BUFFER_DURATION (buffer) = 0;
+
+	return buffer;
+}
+
 void
 arv_viewer_new_buffer_cb (ArvStream *stream, ArvViewer *viewer)
 {
 	ArvBuffer *arv_buffer;
-	GstBuffer *buffer;
 
 	arv_buffer = arv_stream_pop_buffer (stream);
 	if (arv_buffer == NULL)
 		return;
 
 	if (arv_buffer_get_status (arv_buffer) == ARV_BUFFER_STATUS_SUCCESS) {
-		int arv_row_stride;
-		int width, height;
-		char *buffer_data;
-		size_t buffer_size;
+		GstBuffer *buffer;
 		guint64 timestamp_ns;
 
+		buffer = _arv_to_gst_buffer (arv_buffer);
+
 		timestamp_ns =  g_get_real_time () * 1000LL;
 
-		buffer_data = (char *) arv_buffer_get_data (arv_buffer, &buffer_size);
-		arv_buffer_get_image_region (arv_buffer, NULL, NULL, &width, &height);
-		arv_row_stride = width * ARV_PIXEL_FORMAT_BIT_PER_PIXEL (arv_buffer_get_image_pixel_format (arv_buffer)) / 8;
-
-		/* Gstreamer requires row stride to be a multiple of 4 */
-		if ((arv_row_stride & 0x3) != 0) {
-			int gst_row_stride;
-			size_t size;
-			void *data;
-			int i;
-
-			gst_row_stride = (arv_row_stride & ~(0x3)) + 4;
-
-			size = height * gst_row_stride;
-			data = g_malloc (size);	
-
-			for (i = 0; i < height; i++)
-				memcpy (((char *) data) + i * gst_row_stride, buffer_data + i * arv_row_stride, arv_row_stride);
-
-			buffer = gst_buffer_new_wrapped (data, size);
-		} else {
-			buffer = gst_buffer_new_wrapped_full (GST_MEMORY_FLAG_READONLY,
-							      buffer_data, buffer_size,
-							      0, buffer_size, NULL, NULL);
-		}
-
 		if (viewer->timestamp_offset == 0) {
 			viewer->timestamp_offset = timestamp_ns;
 			viewer->last_timestamp = timestamp_ns;
@@ -513,6 +526,16 @@ bus_sync_handler (GstBus *bus, GstMessage *message, gpointer user_data)
 	return GST_BUS_DROP;
 }
 
+static void
+stream_cb (void *user_data, ArvStreamCallbackType type, ArvBuffer *buffer)
+{
+	if (type == ARV_STREAM_CALLBACK_TYPE_INIT) {
+		if (!arv_make_thread_realtime (10) &&
+		    !arv_make_thread_high_priority (-10))
+			g_warning ("Failed to make stream thread high priority");
+	}
+}
+
 void
 arv_viewer_select_camera_cb (GtkComboBox *combo_box, ArvViewer *viewer)
 {
@@ -554,7 +577,7 @@ arv_viewer_select_camera_cb (GtkComboBox *combo_box, ArvViewer *viewer)
 	arv_camera_set_chunk_mode (viewer->camera, FALSE);
 
 	viewer->rotation = 0;
-	viewer->stream = arv_camera_create_stream (viewer->camera, NULL, NULL);
+	viewer->stream = arv_camera_create_stream (viewer->camera, stream_cb, NULL);
 	if (viewer->stream == NULL) {
 		g_object_unref (viewer->camera);
 		viewer->camera = NULL;
@@ -770,7 +793,10 @@ arv_viewer_new (void)
 	gtk_widget_set_no_show_all (viewer->trigger_combo_box, TRUE);
 
 	g_signal_connect (viewer->drawing_area, "realize", G_CALLBACK (drawing_area_realize_cb), viewer);
+
+#if !GTK_CHECK_VERSION (3,14,0)
 	gtk_widget_set_double_buffered (viewer->drawing_area, FALSE);
+#endif
 
 	gtk_widget_show_all (viewer->main_window);
 
@@ -831,6 +857,7 @@ static gboolean
 _gstreamer_plugin_check (void)
 {
 	GstRegistry *registry;
+	GstPluginFeature *feature;
 	unsigned int i;
 	gboolean success = TRUE;
 
@@ -845,8 +872,6 @@ _gstreamer_plugin_check (void)
 	registry = gst_registry_get ();
 
 	for (i = 0; i < G_N_ELEMENTS (plugins); i++) {
-		GstPluginFeature *feature;
-	
 		feature = gst_registry_lookup_feature (registry, plugins[i]);
 		if (!GST_IS_PLUGIN_FEATURE (feature)) {
 			g_print ("Gstreamer plugin '%s' is missing.\n", plugins[i]);
@@ -860,6 +885,13 @@ _gstreamer_plugin_check (void)
 	if (!success)
 		g_print ("Check your gstreamer installation.\n");
 
+	/* Kludge, prevent autoloading of coglsink, which doesn't seem to work for us */
+	feature = gst_registry_lookup_feature (registry, "coglsink");
+	if (GST_IS_PLUGIN_FEATURE (feature)) {
+		gst_plugin_feature_set_rank (feature, GST_RANK_NONE);
+		g_object_unref (feature);
+	}
+
 	return success;
 }
 
